@@ -40,8 +40,8 @@ hourx_wrapper <- function(op, var, infile, outfile, nc34, overwrite, verbose, nc
   
     cmsaf_info <- switch(
       op,
-      paste0("cmsaf::hourmean for variable ", file_data$variable$name),
-      paste0("cmsaf::hoursum for variable ", file_data$variable$name),
+      paste0("cmsafops::hourmean for variable ", file_data$variable$name),
+      paste0("cmsafops::hoursum for variable ", file_data$variable$name),
     )
   
     time_data <- time_bnds[1, ]
