@@ -106,7 +106,7 @@ test_that("attributes are correct", {
   expect_equal(actual, -999)
   
   actual <- ncatt_get(file, "SIS", "cmsaf_info")$value
-  expect_equal(actual, "cmsaf::daysum for variable SIS")
+  expect_equal(actual, "cmsafops::daysum for variable SIS")
   
   global_attr <- ncatt_get(file, 0)
   expect_equal(length(global_attr), 1)
